@@ -19,13 +19,13 @@ if ( -d "t" ) {
 { package PlayTab;
   use App::Music::PlayTab;
   run( "-test",
-       "-output", "${prefix}test.ps",
+       "-output", "${prefix}${base}test.ps",
        "-preamble", "${prefix}dummy.pre",
        "${prefix}${base}.ptb",
      );
 }
 
-my $ok = !differ ("${prefix}test.ps", "${prefix}${base}.ps");
+my $ok = !differ ("${prefix}${base}test.ps", "${prefix}${base}.ps");
 unlink ("${prefix}test.ps") if $ok;
 print $ok ? "" : "not ", "ok 6\n";
 
